@@ -51,8 +51,8 @@ sub parcoord3d
 {
 	if ( not ( @ARGV ) )
 	{
-		$toshell = $main::toshell;
-		#$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
+		$tofile = $main::tofile;
+		#$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
 		say $tee "\n#Now in Sim::OPT::Takechance.\n";
 		$configfile = $main::configfile; #say "dump(\$configfile): " . dump($configfile);
 		@sweeps = @main::sweeps; #say "dump(\@sweeps): " . dump(@sweeps);
@@ -61,12 +61,12 @@ sub parcoord3d
 		@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
 		%vals = %main::vals; #say "dump(\%vals): " . dump(%vals);
 		
-		$mypath = $main::mypath;  #say TOSHELL "dumpINDESCEND(\$mypath): " . dump($mypath);
-		$exeonfiles = $main::exeonfiles; #say TOSHELL "dumpINDESCEND(\$exeonfiles): " . dump($exeonfiles);
+		$mypath = $main::mypath;  #say TOFILE "dumpINDESCEND(\$mypath): " . dump($mypath);
+		$exeonfiles = $main::exeonfiles; #say TOFILE "dumpINDESCEND(\$exeonfiles): " . dump($exeonfiles);
 		$generatechance = $main::generatechance; 
 		$file = $main::file;
 		$preventsim = $main::preventsim;
-		$fileconfig = $main::fileconfig; #say TOSHELL "dumpINDESCEND(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
+		$fileconfig = $main::fileconfig; #say TOFILE "dumpINDESCEND(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
 		$outfile = $main::outfile;
 		$target = $main::target;
 		
